@@ -216,6 +216,7 @@ class PysolMenubar(PysolMenubarTk):
         self.setToolbarState(ms.undo, "undo")
         self.setToolbarState(ms.redo, "redo")
         self.setToolbarState(ms.autodrop, "autodrop")
+        self.setToolbarState(ms.hint, "hint")
         self.setToolbarState(ms.shuffle, "shuffle")
         self.setToolbarState(ms.pause, "pause")
         self.setToolbarState(ms.rules, "rules")
@@ -941,6 +942,11 @@ class PysolToolbar(PysolToolbarTk):
             self.menubar.mShuffle()
         return 1
 
+    def mHint(self, *args):
+        if not self._busy():
+            self.menubar.mHint()
+        return 1
+
     def mPause(self, *args):
         if not self._busy():
             self.menubar.mPause()
