@@ -46,10 +46,10 @@ from pysollib.mygettext import _
 from pysollib.options import Options
 from pysollib.pysolrandom import PysolRandom, construct_random
 from pysollib.pysoltk import HTMLViewer
-from pysollib.pysoltk import HelpStatusbar, PysolStatusbar
 from pysollib.pysoltk import MfxDialog, MfxExceptionDialog, MfxMessageDialog
 from pysollib.pysoltk import MfxScrolledCanvas, TclError
 from pysollib.pysoltk import PysolProgressBar
+from pysollib.pysoltk import PysolStatusbar
 from pysollib.pysoltk import SelectCardsetDialogWithPreview
 from pysollib.pysoltk import SelectDialogTreeData
 from pysollib.pysoltk import destroy_find_card_dialog
@@ -356,10 +356,8 @@ class Application:
         # create the statusbar(s)
         self.statusbar = PysolStatusbar(self.top)
         self.statusbar.show(self.opt.statusbar)
-        self.statusbar.config('gamenumber', self.opt.statusbar_game_number)
-        self.statusbar.config('stuck', self.opt.statusbar_stuck)
-        self.helpbar = HelpStatusbar(self.top)
-        self.helpbar.show(self.opt.helpbar)
+        for w, v in self.opt.statusbar_vars.items():
+            self.statusbar.config(w, v)
         # create the canvas
         self.scrolled_canvas = MfxScrolledCanvas(self.top, propagate=True)
         self.canvas = self.scrolled_canvas.canvas
@@ -601,8 +599,10 @@ class Application:
             return d
         return self._getImagesDir('toolbar', 'default', size, check=False)
 
-    def setTile(self, i, force=0):
-        if self.scrolled_canvas.setTile(self, i, force):
+    def setTile(self, i, scaling=-1, force=0):
+        if scaling == -1:
+            scaling = self.opt.tabletile_scale_method
+        if self.scrolled_canvas.setTile(self, i, scaling, force):
             tile = self.tabletile_manager.get(i)
             if i == 0:
                 self.opt.colors['table'] = tile.color
@@ -877,7 +877,8 @@ class Application:
              self.opt.spread_stacks,
              self.opt.preserve_aspect_ratio) = d.scale_values
             if not self.opt.auto_scale:
-                self.images.resize(self.opt.scale_x, self.opt.scale_y)
+                self.images.resize(self.opt.scale_x, self.opt.scale_y,
+                                   resample=self.opt.resampling)
             if d.cardset_values:
                 cs.CARD_XOFFSET, cs.CARD_YOFFSET = d.cardset_values
                 self.opt.offsets[cs.ident] = d.cardset_values
