@@ -155,6 +155,14 @@ class GI:
         GT_CUSTOM:              n_("Custom"),
     }
 
+    SKILL_LEVELS = {
+        SL_LUCK: _('Luck only'),
+        SL_MOSTLY_LUCK: _('Mostly luck'),
+        SL_BALANCED: _('Balanced'),
+        SL_MOSTLY_SKILL: _('Mostly skill'),
+        SL_SKILL: _('Skill only'),
+    }
+
     #      SELECT_GAME_BY_TYPE = []
     #      for gt, name in TYPE_NAMES.items():
     #          if not name.endswith('games'):
@@ -268,7 +276,8 @@ class GI:
 
     # These obsolete gameids have been used in previous versions of
     # PySol and are no longer supported because of internal changes
-    # (mainly rule changes). The game has been assigned a new id.
+    # (mainly rule changes or removed duplicate games). The game
+    # has been assigned a new id.
     PROTECTED_GAMES = {
          22:  106,              # Double Canfield
          32:  901,              # La Belle Lucie (Midnight Oil)
@@ -276,12 +285,15 @@ class GI:
          72:  115,              # Little Forty
          75:  126,              # Red and Black
          82:  901,              # La Belle Lucie (Midnight Oil)
-         # 155: 5034,              # Mahjongg - Flying Dragon
-         # 156: 5035,              # Mahjongg - Fortress Towers
-         262:  105,              # Canfield
-         902:   88,              # Trefoil
-         904:   68,              # Lexington Harp
-         297:  631,              # Alternation/Alternations
+         155: 5034,             # Mahjongg - Flying Dragon
+         156: 5035,             # Mahjongg - Fortress Towers
+         262: 105,              # Canfield
+         902: 88,               # Trefoil
+         904: 68,               # Lexington Harp
+         237: 22231,            # Three Peaks
+         297: 631,              # Alternation/Alternations
+         526: 447,              # Australian/Outback Patience
+         640: 566,              # Hypotenuse/Brazilian Patience
     }
 
     # For games by compatibility, note that missing games may actually
@@ -318,16 +330,16 @@ class GI:
         # Gnome AisleRiot 2.2.0 (we have 65 out of 70 games)
         # Gnome AisleRiot 3.22.7
         #   still missing:
-        #       Hamilton, Isabel, King's Audience, Labyrinth, Napoleon's Tomb,
-        #       Saratoga, Thieves, Treize, Valentine, Wall
+        #       Hamilton, Isabel, King's Audience, Labyrinth, Thieves,
+        #       Treize, Valentine, Wall
         ("Gnome AisleRiot", (
             1, 2, 8, 9, 11, 12, 13, 19, 24, 27, 29, 31, 33, 34, 35, 36,
             38, 40, 41, 42, 43, 45, 48, 58, 65, 67, 89, 91, 92, 93, 94,
             95, 96, 97, 100, 104, 105, 111, 112, 113, 130, 135, 139, 144,
             146, 147, 148, 200, 201, 206, 224, 225, 229, 230, 233, 257,
-            258, 280, 281, 282, 283, 284, 334, 384, 495, 551, 552, 553,
-            572, 593, 674, 700, 715, 716, 737, 772, 810, 819, 824, 829,
-            22231,
+            258, 277, 280, 281, 282, 283, 284, 334, 384, 479, 495, 551,
+            552, 553, 572, 593, 674, 700, 715, 716, 737, 772, 810, 819,
+            824, 829, 22231,
         )),
 
         # Hoyle Card Games
@@ -388,16 +400,16 @@ class GI:
         #       Desert Fox, Deuces and Queens, Double Antares,
         #       Double Antarctica, Double Arctica, Double Baker's Spider,
         #       Double Cascade, Double Fourteens, Double Line 8,
-        #       Double Majesty, Double Sea Towers, Double Spidercells,
-        #       Doublet Cell 5, Doubt, Dream Fan, Dumfries Cell,
-        #       Falcon Wing, Fan Nine, Fanny 6, Four By Ten, FreeCell AK,
-        #       Gaps Alter, Gaps Diff, George V, Grandmother's Clock,
-        #       In a Frame, Inverted FreeCell, Kings, Klondike FreeCell,
-        #       La Cabane, La Double Entente, Little Gazette, Magic FreeCell,
-        #       Mini Gaps, Montreal, Napoleon at Iena, Napoleon at Waterloo,
-        #       Napoleon's Guards, Nationale, Oasis, Opera, Ordered Suits,
-        #       Osmotic FreeCell, Pair FreeCell, Pairs 2, Petal,
-        #       Reserved Thirteens, Sea Spider, Sept Piles 0, Short Solitaire,
+        #       Double Majesty, Double Spidercells, Doublet Cell 5, Doubt,
+        #       Dream Fan, Dumfries Cell, Falcon Wing, Fan Nine, Fanny 6,
+        #       Four By Ten, FreeCell AK, Gaps Alter, Gaps Diff, George V,
+        #       Grandmother's Clock, In a Frame, Inverted FreeCell, Kings,
+        #       Klondike FreeCell, La Cabane, La Double Entente,
+        #       Little Gazette, Magic FreeCell, Mini Gaps, Montreal,
+        #       Napoleon at Iena, Napoleon at Waterloo, Napoleon's Guards,
+        #       Nationale, Oasis, Opera, Ordered Suits, Osmotic FreeCell,
+        #       Pair FreeCell, Pairs 2, Petal, Reserved Thirteens,
+        #       Sea Spider, Sept Piles 0, Short Solitaire,
         #       Simple Alternations, Smart Osmosis, Step By Step, Strategy 7,
         #       Stripped FreeCell, Tarantula, Triple Dispute, Trusty Twenty,
         #       Two Ways 3, Up Or Down, Versailles, Vertical FreeCell,
@@ -410,8 +422,8 @@ class GI:
             303, 309, 314, 318, 320, 322, 324, 325, 336, 338, 341, 363,
             364, 372, 376, 383, 384, 385, 386, 390, 391, 393, 398, 405,
             415, 416, 425, 451, 453, 461, 464, 466, 467, 476, 480, 484,
-            511, 512, 516, 561, 610, 625, 629, 631, 638, 641, 647, 650,
-            655, 678, 734, 751, 784, 825, 829, 834, 837, 844, 901,
+            511, 512, 513, 516, 561, 610, 625, 629, 631, 638, 641, 647,
+            650, 655, 678, 734, 751, 784, 825, 829, 834, 837, 844, 901,
         )),
 
         # xpat2 1.06 (we have 14 out of 16 games)
@@ -484,7 +496,8 @@ class GI:
         ("3.21", (143, 144)),
         ("3.30", (145, 146, 147, 148, 149, 150, 151)),
         ("3.40", (152, 153, 154)),
-        ("4.00", (157, 158, 159, 160, 161, 162, 163, 164)),
+        ("4.00", (5034, 5035, 157, 158, 159, 160, 161, 162, 163, 164)),
+        ('4.10', tuple(range(5001, 5034)) + tuple(range(5036, 5103))),
         ("4.20", (165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
                   175, 176, 177, 178)),
         ("4.30", (179, 180, 181, 182, 183, 184)),
@@ -495,7 +508,7 @@ class GI:
                   210, 211, 212, 213, 214, 215, 216, 217, 218, 219,
                   220, 221, 222, 223, 224, 225, 226, 227, 228, 229,
                   230, 231, 232, 233, 234, 235, 236)),
-        ("4.70", (237,)),
+        ("4.70", (237, 22231)),
         ('fc-0.5.0', (  # moved from Ultrasol
                       # 121, 122, 187, 188, 189, 190, 191, 192, 194, 197, 198,
                       5301, 5302, 9011, 11001, 11002, 11003, 11004, 11005,
@@ -513,7 +526,9 @@ class GI:
                       16666, 16667, 16668, 16669, 16670, 16671, 16672, 16673,
                       16674, 16675, 16676, 16677, 16678, 16679, 16680, 22216,
                       22223, 22224, 22225, 22226, 22227, 22228, 22229, 22230,
-                      22231, 22232,)),
+                      22232, ) +
+         tuple(range(5200, 5280)) + tuple(range(5401, 5415)) +
+         tuple(range(5801, 5811)) + tuple(range(5901, 5906))),
         ('fc-0.8.0', tuple(range(263, 323))),  # exclude 297
         ('fc-0.9.0', tuple(range(323, 421))),
         ('fc-0.9.1', tuple(range(421, 441))),
@@ -523,7 +538,7 @@ class GI:
         ('fc-1.0',   tuple(range(671, 711))),
         ('fc-1.1',   tuple(range(711, 759))),
         ('fc-2.0',   tuple(range(11011, 11014)) + tuple(range(759, 767))),
-        ('fc-2.1',   tuple(range(767, 774)) + (555001,)),
+        ('fc-2.1',   tuple(range(767, 774)) + (1900, 1901, 555001,)),
         ('fc-2.8',   (343001,)),
         ('fc-2.12',   tuple(range(774, 811)) + (16681,) +
          tuple(range(22217, 22219))),
