@@ -367,6 +367,8 @@ class Primrose(Interregnum):
 
 # ************************************************************************
 # * Colorado
+# * Double Line
+# * Grandfather
 # ************************************************************************
 
 class Colorado_RowStack(OpenStack):
@@ -396,7 +398,7 @@ class Colorado(Game):
             roff = l.YOFFSET * (tableau_max - 1)
 
         self.setSize(l.XM + 10 * l.XS,
-                     l.YM + 4 * l.YS + l.TEXT_HEIGHT + (2 * roff))
+                     l.YM + 4 * l.YS + (2 * l.TEXT_HEIGHT) + (2 * roff))
 
         # create stacks
         x, y, = l.XS, l.YM
@@ -422,13 +424,14 @@ class Colorado(Game):
                 x += l.XS
             y += l.YS + roff
 
-        x, y = l.XM + 9 * l.XS, self.height - l.YS
+        x, y = l.XM + 9 * l.XS, self.height - l.YS - l.TEXT_HEIGHT
         s.talon = WasteTalonStack(x, y, self, max_rounds=max_rounds)
-        l.createText(s.talon, "n")
+        l.createText(s.talon, "s")
         x -= l.XS
         s.waste = WasteStack(x, y, self, max_cards=waste_max)
+        l.createText(s.waste, "s")
         if max_rounds > 1:
-            l.createRoundText(s.waste, "s")
+            l.createRoundText(s.talon, "n")
 
         # define stack-groups
         l.defaultStackGroups()
@@ -460,8 +463,8 @@ class Grandfather_RowStack(BasicRowStack):
 class Grandfather(Colorado):
     RowStack_Class = Grandfather_RowStack
 
-    def createGame(self):
-        Colorado.createGame(self, waste_max=999999, max_rounds=2,
+    def createGame(self, max_rounds=2):
+        Colorado.createGame(self, waste_max=999999, max_rounds=max_rounds,
                             tableau_max=2)
 
     def startGame(self):
@@ -473,6 +476,12 @@ class Grandfather(Colorado):
         return cards
 
 
+class DoubleLine(Grandfather):
+
+    def createGame(self):
+        Grandfather.createGame(self, max_rounds=1)
+
+
 # ************************************************************************
 # * Amazons
 # ************************************************************************
@@ -507,7 +516,7 @@ class Amazons_Foundation(AbstractFoundationStack):
             return False
         if from_stack not in self.game.s.rows:
             return False
-        if cards[0].rank == ACE:
+        if cards[0].rank == ACE and not self.cards:
             return True
         if not self.cards:
             return False
@@ -525,7 +534,8 @@ class Amazons_Foundation(AbstractFoundationStack):
 
 class Amazons(AuldLangSyne):
     Talon_Class = StackWrapper(Amazons_Talon, max_rounds=-1)
-    Foundation_Class = StackWrapper(Amazons_Foundation, max_cards=7)
+    Foundation_Class = StackWrapper(Amazons_Foundation, max_cards=7,
+                                    suit=ANY_SUIT)
 
     def _shuffleHook(self, cards):
         return cards
@@ -662,6 +672,9 @@ registerGame(GameInfo(569, Primrose, "Primrose",
 registerGame(GameInfo(636, StrategyPlus, "Strategy +",
                       GI.GT_NUMERICA, 1, 0, GI.SL_SKILL))
 registerGame(GameInfo(688, Formic, "Formic",
-                      GI.GT_NUMERICA, 1, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_NUMERICA, 1, 0, GI.SL_MOSTLY_SKILL,
+                      altnames=("Ants",)))
+registerGame(GameInfo(702, DoubleLine, "Double Line",
+                      GI.GT_NUMERICA, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(853, Grandfather, "Grandfather",
                       GI.GT_NUMERICA, 2, 1, GI.SL_BALANCED))
