@@ -33,6 +33,7 @@ from pysollib.mygettext import _
 from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
         AbstractFoundationStack, \
+        AutoDealTalonStack, \
         BasicRowStack, \
         DealRowTalonStack, \
         InitialDealTalonStack, \
@@ -810,7 +811,7 @@ class Vague(Game):
         self.setSize(layout.XM+maxrows*layout.XS, layout.YM+(rows+1)*layout.YS)
 
         x, y = layout.XM, layout.YM
-        s.talon = TalonStack(x, y, self)
+        s.talon = AutoDealTalonStack(x, y, self)
         layout.createText(s.talon, 'ne')
 
         x, y = layout.XM+2*layout.XS, layout.YM
@@ -977,11 +978,11 @@ class DevilsSolitaire(Game):
 
         x, y = layout.XM+4.5*layout.XS, self.height-layout.YS
         s.talon = WasteTalonStack(x, y, self, max_rounds=3)
-        layout.createText(s.talon, 'n')
-        layout.createRoundText(s.talon, 'nnn')
+        layout.createText(s.talon, 'se')
+        layout.createRoundText(s.talon, 'n')
         x -= layout.XS
         s.waste = DevilsSolitaire_WasteStack(x, y, self)
-        layout.createText(s.waste, 'n')
+        layout.createText(s.waste, 'sw')
 
         layout.defaultStackGroups()
 
@@ -1163,7 +1164,7 @@ class NapoleonLeavesMoscow(NapoleonTakesMoscow):
 
 # ************************************************************************
 # * Flake
-# * Flake (2 decks)
+# * Flake (2 Decks)
 # ************************************************************************
 
 
@@ -1312,7 +1313,7 @@ registerGame(GameInfo(734, NapoleonLeavesMoscow, "Napoleon Leaves Moscow",
 registerGame(GameInfo(749, Flake, "Flake",
                       GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL,
                       1, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(750, Flake2Decks, "Flake (2 decks)",
+registerGame(GameInfo(750, Flake2Decks, "Flake (2 Decks)",
                       GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL,
                       2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(763, Wasatch, "Wasatch",
