@@ -32,14 +32,17 @@ from pysollib.mfxutil import kwdefault
 from pysollib.stack import \
         AC_RowStack, \
         BO_RowStack, \
+        DealRowTalonStack, \
         KingAC_RowStack, \
         KingSS_RowStack, \
+        OpenStack, \
         SS_FoundationStack, \
         SS_RowStack, \
         Spider_SS_RowStack, \
         StackWrapper, \
         WasteStack, \
-        WasteTalonStack
+        WasteTalonStack, \
+        isAlternateColorSequence
 from pysollib.util import ACE, KING
 
 # ************************************************************************
@@ -72,9 +75,7 @@ class DoubleKlondike(Game):
         l.defaultAll()
         # extra
         if max_rounds > 1:
-            anchor = 'nn'
-            if layout.get("texts"):
-                anchor = 'nnn'
+            anchor = 'n'
             l.createRoundText(s.talon, anchor)
         return l
 
@@ -245,15 +246,15 @@ class BigDeal(DoubleKlondike):
                     SS_FoundationStack(x, y, self, suit=j % 4))
                 y += l.YS
             x += l.XS
-        x, y = l.XM, self.height-l.YS
+        x, y = l.XM, self.height - l.YS - l.TEXT_HEIGHT
         s.talon = WasteTalonStack(x, y, self, max_rounds=max_rounds)
-        l.createText(s.talon, 'n')
+        l.createText(s.talon, 's')
         x += l.XS
         s.waste = WasteStack(x, y, self)
         s.waste.CARD_XOFFSET = XOFFSET
-        l.createText(s.waste, 'n')
+        l.createText(s.waste, 's')
         if max_rounds > 1:
-            l.createRoundText(s.talon, 'nnn')
+            l.createRoundText(s.talon, 'n')
         self.setRegion(s.rows, (-999, -999, l.XM+rows*l.XS-l.CW//2, 999999),
                        priority=1)
         l.defaultStackGroups()
@@ -333,6 +334,72 @@ class Brush(DoubleKlondike):
     getQuickPlayScore = Game._getSpiderQuickPlayScore
 
 
+# ************************************************************************
+# * Churchill Solitaire
+# ************************************************************************
+# https://boardgames.stackexchange.com/questions/29254/rules-for-churchill-solitaire
+
+class Churchill_DevilStack(OpenStack):
+    def getHelp(self):
+        return "Devil's Six. Must be played directly to Foundations."
+
+
+class Churchill_RowStack(KingAC_RowStack):
+    def acceptsCards(self, from_stack, cards):
+        if isinstance(from_stack, Churchill_DevilStack):
+            return False
+        return KingAC_RowStack.acceptsCards(self, from_stack, cards)
+
+
+class Churchill_TalonStack(DealRowTalonStack):
+    def dealCards(self, sound=False):
+        def isKingPile(cards):
+            return len(cards) > 0 and \
+                cards[0].rank == KING and \
+                isAlternateColorSequence(cards)
+        rows = [r for r in self.game.s.rows if not isKingPile(r.cards)]
+        return self.dealRowAvail(rows=rows, sound=sound)
+
+
+class Churchill(Game):
+    Layout_Method = staticmethod(Layout.harpLayout)
+    Talon_Class = Churchill_TalonStack
+    Foundation_Class = SS_FoundationStack
+    RowStack_Class = Churchill_RowStack
+
+    shallHighlightMatch = Game._shallHighlightMatch_AC
+
+    def createGame(self, **layout):
+        # create layout
+        l, s = Layout(self), self.s
+        kwdefault(layout, rows=10, waste=0, texts=1, playcards=30, reserves=1)
+        self.Layout_Method(l, **layout)
+        self.setSize(l.size[0], l.size[1])
+        # create stacks
+        s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self)
+        for r in l.s.foundations:
+            s.foundations.append(
+                self.Foundation_Class(r.x, r.y, self, suit=r.suit, max_move=0))
+        for r in l.s.rows:
+            s.rows.append(self.RowStack_Class(r.x, r.y, self))
+        for r in l.s.reserves:
+            stack = Churchill_DevilStack(r.x, r.y, self)
+            stack.CARD_XOFFSET = l.XOFFSET
+            stack.CARD_YOFFSET = 0
+            s.reserves.append(stack)
+        # default
+        l.defaultAll()
+        return l
+
+    def startGame(self):
+        for i in range(1, 5):
+            self.s.talon.dealRow(rows=self.s.rows[i:-i], flip=0, frames=0)
+        self.startDealSample()
+        for i in range(6):
+            self.s.talon.dealRow(rows=[self.s.reserves[0]])
+        self._startAndDealRow()
+
+
 # register the game
 registerGame(GameInfo(21, DoubleKlondike, "Double Klondike",
                       GI.GT_KLONDIKE, 2, -1, GI.SL_BALANCED))
@@ -360,7 +427,7 @@ registerGame(GameInfo(562, Delivery, "Delivery",
                       GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 4, 0,
                       GI.SL_BALANCED))
 registerGame(GameInfo(590, ChineseKlondike, "Chinese Klondike",
-                      GI.GT_KLONDIKE, 3, -1, GI.SL_BALANCED,
+                      GI.GT_KLONDIKE | GI.GT_STRIPPED, 3, -1, GI.SL_BALANCED,
                       suits=(0, 1, 2)))
 registerGame(GameInfo(591, Pantagruel, "Pantagruel",
                       GI.GT_KLONDIKE, 2, 0, GI.SL_BALANCED))
@@ -369,7 +436,10 @@ registerGame(GameInfo(668, DoubleKingsley, "Double Kingsley",
 registerGame(GameInfo(678, ThievesOfEgypt, "Thieves of Egypt",
                       GI.GT_KLONDIKE, 2, 1, GI.SL_BALANCED))
 registerGame(GameInfo(689, Brush, "Brush",
-                      GI.GT_2DECK_TYPE | GI.GT_ORIGINAL, 2, 0,
+                      GI.GT_SPIDER | GI.GT_ORIGINAL, 2, 0,
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(822, DoubleTrigon, "Double Trigon",
                       GI.GT_KLONDIKE, 2, -1, GI.SL_BALANCED))
+registerGame(GameInfo(828, Churchill, "Churchill",
+                      GI.GT_GYPSY, 2, 0, GI.SL_BALANCED,
+                      altnames=('Prime Minister')))
