@@ -27,6 +27,7 @@ from pysollib.hint import DefaultHint
 from pysollib.layout import Layout
 from pysollib.stack import \
         AbstractFoundationStack, \
+        AutoDealTalonStack, \
         BasicRowStack, \
         DealRowRedealTalonStack, \
         InitialDealTalonStack, \
@@ -49,7 +50,7 @@ class MonteCarlo_Hint(DefaultHint):
 
 # ************************************************************************
 # * Monte Carlo
-# * Monte Carlo (2 decks)
+# * Monte Carlo (2 Decks)
 # ************************************************************************
 
 class MonteCarlo_Talon(TalonStack):
@@ -316,7 +317,7 @@ class SimplePairs(MonteCarlo):
                                                   max_accept=1, max_cards=2,
                                                   dir=0, base_rank=NO_RANK))
         x, y = l.XM, l.YM + 3*l.YS//2
-        s.talon = TalonStack(x, y, self, max_rounds=1)
+        s.talon = AutoDealTalonStack(x, y, self, max_rounds=1)
         l.createText(s.talon, "s")
         x = x + 5*l.XS
         s.foundations.append(self.Foundation_Class(x, y, self, suit=ANY_SUIT,
@@ -851,7 +852,7 @@ class DerLetzteMonarch(Game):
 
 
 class TheLastMonarchII(DerLetzteMonarch):
-    Talon_Class = TalonStack
+    Talon_Class = AutoDealTalonStack
 
     def createGame(self):
         DerLetzteMonarch.createGame(self, texts=True)
@@ -883,7 +884,7 @@ class DoubletsII(Game):
                                           dir=0, base_rank=NO_RANK))
             x += l.XS
         x, y = l.XM, self.height-l.YS
-        s.talon = TalonStack(x, y, self)
+        s.talon = AutoDealTalonStack(x, y, self)
         l.createText(s.talon, 'n')
 
         x, y = self.width-l.XS, self.height-l.YS
@@ -963,7 +964,7 @@ class RightAndLeft(Game):
 registerGame(GameInfo(89, MonteCarlo, "Monte Carlo",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
                       altnames=("Quilt",)))
-registerGame(GameInfo(216, MonteCarlo2Decks, "Monte Carlo (2 decks)",
+registerGame(GameInfo(216, MonteCarlo2Decks, "Monte Carlo (2 Decks)",
                       GI.GT_PAIRING_TYPE, 2, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(212, Weddings, "Weddings",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
@@ -988,7 +989,7 @@ registerGame(GameInfo(152, DerLetzteMonarch, "The Last Monarch",
 registerGame(GameInfo(328, TheWish, "The Wish",
                       GI.GT_PAIRING_TYPE | GI.GT_STRIPPED, 1, 0,
                       GI.SL_MOSTLY_LUCK, ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
-registerGame(GameInfo(329, TheWishOpen, "The Wish (open)",
+registerGame(GameInfo(329, TheWishOpen, "The Wish (Open)",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL |
                       GI.GT_STRIPPED, 1, 0, GI.SL_MOSTLY_SKILL,
                       ranks=(0, 6, 7, 8, 9, 10, 11, 12),
