@@ -1191,7 +1191,7 @@ class Ladybug(Game):
 # register the game
 registerGame(GameInfo(257, Numerica, "Numerica",
                       GI.GT_NUMERICA | GI.GT_CONTRIB, 1, 0, GI.SL_BALANCED,
-                      altnames=("Sir Tommy",)))
+                      altnames=("Sir Tommy", "Old Patience",)))
 registerGame(GameInfo(171, LadyBetty, "Lady Betty",
                       GI.GT_NUMERICA, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(355, Frog, "Frog",
@@ -1214,7 +1214,7 @@ registerGame(GameInfo(435, Shifting, "Shifting",
                       GI.GT_NUMERICA, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(472, Strategerie, "Strategerie",
                       GI.GT_NUMERICA, 1, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(558, Numerica2Decks, "Numerica (2 decks)",
+registerGame(GameInfo(558, Numerica2Decks, "Numerica (2 Decks)",
                       GI.GT_NUMERICA, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(589, LastChance, "Last Chance",
                       GI.GT_NUMERICA, 1, 0, GI.SL_BALANCED))
