@@ -21,16 +21,10 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import AbstractHint
-
-from pysollib.util import ACE, KING, QUEEN
-
+from pysollib.layout import Layout
 from pysollib.stack import \
         BasicRowStack, \
         DealRowTalonStack, \
@@ -42,6 +36,7 @@ from pysollib.stack import \
         StackWrapper, \
         WasteStack, \
         WasteTalonStack
+from pysollib.util import ACE, KING, QUEEN
 
 # ************************************************************************
 # *
@@ -140,14 +135,15 @@ class PictureGallery_Hint(AbstractHint):
 class PictureGallery_Foundation(RK_FoundationStack):
     def __init__(self, x, y, game):
         RK_FoundationStack.__init__(
-            self, x, y, game, base_rank=ACE, dir=0, max_move=0, max_cards=8)
+            self, x, y, game, base_rank=ACE, dir=0, max_move=0,
+            max_cards=(4 * game.gameinfo.decks))
         self.CARD_YOFFSET = min(30, self.game.app.images.CARD_YOFFSET + 10)
 
     def getBottomImage(self):
         return self.game.app.images.getLetter(ACE)
 
     def closeStack(self):
-        if len(self.cards) == 8:
+        if len(self.cards) == (4 * self.game.gameinfo.decks):
             if self.game.moves.state not in \
                     (self.game.S_REDO, self.game.S_RESTORE):
                 self.game.flipAllMove(self)
@@ -209,36 +205,38 @@ class PictureGallery(Game):
     # game layout
     #
 
-    def createGame(self, waste=False):
+    def createGame(self, waste=False, numstacks=8):
         rows = len(self.TableauStack_Classes)
         # create layout
         l, s = Layout(self), self.s
-        TABLEAU_YOFFSET = min(9, max(3, l.YOFFSET // 3))
+        numtableau = (4 * self.gameinfo.decks)
+        TABLEAU_YOFFSET = min(numtableau + 1, max(3, l.YOFFSET // 3))
 
         # set window
-        th = l.YS + (12//rows-1) * TABLEAU_YOFFSET
+        th = l.YS + ((numtableau + 4) // rows - 1) * TABLEAU_YOFFSET
         # (set piles so that at least 2/3 of a card is visible with 10 cards)
-        h = (10-1)*l.YOFFSET + l.CH*2//3
-        self.setSize(10*l.XS+l.XM, l.YM + 3*th + l.YM + h)
+        h = ((numtableau + 2) - 1) * l.YOFFSET + l.CH * 2 // 3
+        self.setSize((numtableau + 2) * l.XS + l.XM, l.YM + 3 * th + l.YM + h)
 
         # create stacks
         s.addattr(tableaux=[])     # register extra stack variable
-        x = l.XM + 8 * l.XS + l.XS // 2
+        x = l.XM + numtableau * l.XS + l.XS // 2
         y = l.YM + l.CH // 2
         s.foundations.append(self.Foundation_Class(x, y, self))
         y = l.YM
         for cl in self.TableauStack_Classes:
             x = l.XM
-            for j in range(8):
+            for j in range(numtableau):
                 s.tableaux.append(cl(x, y, self, yoffset=TABLEAU_YOFFSET))
                 x = x + l.XS
             y = y + th
+        self.setRegion(s.foundations, (x - l.CW // 2, -999, 999999, y - l.CH))
         x, y = l.XM, y + l.YM
-        for i in range(8):
+        for i in range(numstacks):
             s.rows.append(self.RowStack_Class(x, y, self))
             x = x + l.XS
         # self.setRegion(s.rows, (-999, -999, x - l.CW // 2, 999999))
-        x = l.XM + 8 * l.XS + l.XS // 2
+        x = l.XM + numstacks * l.XS + l.XS // 2
         y = self.height - l.YS
         s.talon = self.Talon_Class(x, y, self)
         l.createText(s.talon, "se")
@@ -246,7 +244,6 @@ class PictureGallery(Game):
             y -= l.YS
             s.waste = WasteStack(x, y, self)
             l.createText(s.waste, "se")
-        self.setRegion(s.foundations, (x - l.CW // 2, -999, 999999, y - l.CH))
 
         # define stack-groups
         if waste:
@@ -266,7 +263,7 @@ class PictureGallery(Game):
         self._startAndDealRow()
 
     def isGameWon(self):
-        if len(self.s.foundations[0].cards) != 8:
+        if len(self.s.foundations[0].cards) != (4 * self.gameinfo.decks):
             return False
         for stack in self.s.tableaux:
             if len(stack.cards) != 4:
@@ -290,6 +287,7 @@ class PictureGallery(Game):
 
 # ************************************************************************
 # * Great Wheel
+# * Greater Wheel
 # ************************************************************************
 
 
@@ -334,7 +332,7 @@ class GreatWheel(PictureGallery):
     Talon_Class = StackWrapper(WasteTalonStack, max_rounds=1)
 
     def createGame(self):
-        PictureGallery.createGame(self, waste=True)
+        PictureGallery.createGame(self, waste=True, numstacks=8)
 
     def fillStack(self, stack):
         if stack is self.s.waste and not stack.cards:
@@ -342,7 +340,7 @@ class GreatWheel(PictureGallery):
         if self.s.talon.cards or self.s.waste.cards:
             if stack in self.s.rows and len(stack.cards) == 0:
                 old_state = self.enterState(self.S_FILL)
-                for i in range(4):
+                for i in range(2 + self.gameinfo.decks):
                     if not self.s.waste.cards:
                         self.s.talon.dealCards()
                     if self.s.waste.cards:
@@ -350,13 +348,14 @@ class GreatWheel(PictureGallery):
                 self.leaveState(old_state)
 
     def startGame(self):
+        for i in range(1 + self.gameinfo.decks):
+            self.s.talon.dealRow(frames=0)
         self.startDealSample()
-        for i in range(4):
-            self.s.talon.dealRow()
+        self.s.talon.dealRow()
         self.s.talon.dealCards()
 
     def isGameWon(self):
-        if len(self.s.foundations[0].cards) != 8:
+        if len(self.s.foundations[0].cards) != (4 * self.gameinfo.decks):
             return False
         if self.s.talon.cards or self.s.waste.cards:
             return False
@@ -371,6 +370,12 @@ class GreatWheel(PictureGallery):
         return (card1.suit == card2.suit and
                 (card1.rank + 2 == card2.rank or card2.rank + 2 == card1.rank))
 
+
+class GreaterWheel(GreatWheel):
+
+    def createGame(self):
+        PictureGallery.createGame(self, waste=True, numstacks=12)
+
 # ************************************************************************
 # * Mount Olympus
 # * Zeus
@@ -463,6 +468,7 @@ class Zeus(MountOlympus):
 
 # ************************************************************************
 # * Royal Parade
+# * Big Parade
 # ************************************************************************
 
 
@@ -512,18 +518,25 @@ class RoyalParade(PictureGallery):
         ]
     RowStack_Class = StackWrapper(BasicRowStack, max_accept=0)
 
-    def createGame(self):
-        PictureGallery.createGame(self)
+    def createGame(self, numstacks=8):
+        PictureGallery.createGame(self, numstacks=numstacks)
         self.s.internals.append(InvisibleStack(self))
 
     def startGame(self):
         self.startDealSample()
-        self.s.talon.dealRow(rows=self.s.tableaux)
+        self.s.talon.dealRow(rows=self.s.tableaux, frames=0)
         self.s.talon.dealRow()
 
 
+class BigParade(RoyalParade):
+
+    def createGame(self):
+        RoyalParade.createGame(self, numstacks=12)
+
+
 # ************************************************************************
 # * Virginia Reel
+# * Three Up
 # ************************************************************************
 
 class VirginiaReel_Talon(DealRowTalonStack):
@@ -554,23 +567,30 @@ class VirginiaReel(RoyalParade):
         return cards+bottom_cards
 
     def startGame(self):
-        self.s.talon.dealRow(rows=self.s.tableaux[0::8], frames=0)
+        numdeal = (4 * self.gameinfo.decks)
+        self.s.talon.dealRow(rows=self.s.tableaux[0::numdeal], frames=0)
         self.startDealSample()
         for i in range(3):
-            rows = self.s.tableaux[i*8+1:i*8+8]
-            self.s.talon.dealRow(rows=rows)
+            rows = self.s.tableaux[i*numdeal+1:i*numdeal+numdeal]
+            self.s.talon.dealRow(rows=rows, frames=0)
         self.s.talon.dealRow()
 
     def fillStack(self, stack):
         pass
 
 
+class ThreeUp(VirginiaReel):
+
+    def createGame(self):
+        VirginiaReel.createGame(self, numstacks=12)
+
+
 # register the game
 registerGame(GameInfo(7, PictureGallery, "Picture Gallery",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED,
                       altnames=("Die Bildgallerie", "Mod-3")))
 registerGame(GameInfo(397, GreatWheel, "Great Wheel",
-                      GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED,
+                      GI.GT_2DECK_TYPE | GI.GT_STRIPPED, 2, 0, GI.SL_BALANCED,
                       ranks=list(range(12))  # without Kings
                       ))
 registerGame(GameInfo(398, MountOlympus, "Mount Olympus",
@@ -579,6 +599,14 @@ registerGame(GameInfo(399, Zeus, "Zeus",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(546, RoyalParade, "Royal Parade",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_SKILL,
-                      rules_filename='virginiareel.html'))
+                      altnames=("Hussars", "Financier")))
 registerGame(GameInfo(547, VirginiaReel, "Virginia Reel",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(782, GreaterWheel, "Greater Wheel",
+                      GI.GT_4DECK_TYPE | GI.GT_STRIPPED, 4, 0, GI.SL_BALANCED,
+                      ranks=list(range(12))  # without Kings
+                      ))
+registerGame(GameInfo(803, BigParade, "Big Parade",
+                      GI.GT_3DECK_TYPE, 3, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(804, ThreeUp, "Three Up",
+                      GI.GT_3DECK_TYPE, 3, 0, GI.SL_MOSTLY_SKILL))
