@@ -28,6 +28,7 @@ from pysollib.layout import Layout
 from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
         AbstractFoundationStack, \
+        AutoDealTalonStack, \
         BasicRowStack, \
         DealReserveRedealTalonStack, \
         DealRowTalonStack, \
@@ -37,7 +38,6 @@ from pysollib.stack import \
         ReserveStack, \
         Stack, \
         StackWrapper, \
-        TalonStack, \
         WasteStack, \
         WasteTalonStack, \
         getNumberOfFreeStacks
@@ -458,7 +458,7 @@ class Thirteens(Pyramid):
                 x += layout.XS
             y += layout.YS
         x, y = layout.XM, self.height-layout.YS
-        s.talon = TalonStack(x, y, self)
+        s.talon = AutoDealTalonStack(x, y, self)
         layout.createText(s.talon, 'n')
         x, y = self.width-layout.XS, self.height-layout.YS
         s.foundations.append(Pyramid_Foundation(x, y, self,
@@ -543,7 +543,7 @@ class Elevens(Pyramid):
             layout.YM + (rows + rp) * layout.YS)
 
         x, y = self.width-layout.XS, layout.YM
-        s.talon = TalonStack(x, y, self)
+        s.talon = AutoDealTalonStack(x, y, self)
         layout.createText(s.talon, 's')
         x, y = self.width-layout.XS, self.height-layout.YS
         s.foundations.append(AbstractFoundationStack(x, y, self,
@@ -1420,7 +1420,7 @@ class Hurricane(Pyramid):
             x += layout.XS
 
         x, y = layout.XM, layout.YM
-        s.talon = TalonStack(x, y, self)
+        s.talon = AutoDealTalonStack(x, y, self)
         layout.createText(s.talon, 'ne')
         y += 2*layout.YS
         s.foundations.append(AbstractFoundationStack(x, y, self,
@@ -1469,7 +1469,7 @@ registerGame(GameInfo(596, SuitElevens, "Suit Elevens",
 registerGame(GameInfo(597, Fifteens, "Fifteens",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(619, TripleAlliance, "Triple Alliance",
-                      GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0,
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL, altnames=('Triplets',)))
 registerGame(GameInfo(655, Pharaohs, "Pharaohs",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_BALANCED))
@@ -1487,7 +1487,8 @@ registerGame(GameInfo(677, TwoPyramids, "Two Pyramids",
                       GI.GT_PAIRING_TYPE | GI.GT_ORIGINAL, 2, 2,
                       GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(681, KingTut, "King Tut",
-                      GI.GT_PAIRING_TYPE, 1, -1, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE, 1, -1, GI.SL_MOSTLY_LUCK,
+                      altnames=("Tut's Tomb",)))
 registerGame(GameInfo(699, DoublePyramid, "Double Pyramid",
                       GI.GT_PAIRING_TYPE, 2, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(700, Triangle, "Triangle",
@@ -1501,8 +1502,8 @@ registerGame(GameInfo(735, Hurricane, "Hurricane",
 registerGame(GameInfo(796, Exit, "Exit",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL, altnames=('Gay Gordons',)))
-registerGame(GameInfo(802, TripleAlliance2Decks, "Triple Alliance (2 decks)",
-                      GI.GT_2DECK_TYPE | GI.GT_OPEN, 2, 0,
+registerGame(GameInfo(802, TripleAlliance2Decks, "Triple Alliance (2 Decks)",
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 2, 0,
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(846, PyramidDozen, "Pyramid Dozen",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_BALANCED))
