@@ -21,33 +21,27 @@
 #
 # ---------------------------------------------------------------------------##
 
-# Imports
-
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.mfxutil import kwdefault
 from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import CautiousDefaultHint
-from pysollib.pysoltk import MfxCanvasText
-
-from pysollib.games.braid import Braid_Foundation, Braid_BraidStack, \
-     Braid_RowStack, Braid_ReserveStack, Braid
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.games.bakersdozen import Cruel_Talon
-
-from pysollib.util import ANY_RANK, NO_RANK, UNLIMITED_ACCEPTS, UNLIMITED_MOVES
-
+from pysollib.games.braid import Braid, Braid_ReserveStack, Braid_RowStack
+from pysollib.games.braid import Braid_BraidStack, Braid_Foundation
+from pysollib.hint import CautiousDefaultHint
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
+from pysollib.mygettext import _
+from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
         InitialDealTalonStack, \
         OpenStack, \
         RK_RowStack, \
         ReserveStack, \
         SS_FoundationStack, \
+        SS_RowStack, \
         StackWrapper, \
         WasteStack, \
-        WasteTalonStack, \
-        SS_RowStack
+        WasteTalonStack
+from pysollib.util import ANY_RANK, NO_RANK, UNLIMITED_ACCEPTS, UNLIMITED_MOVES
 
 # ************************************************************************
 # * Tarock Talon Stacks
@@ -930,7 +924,7 @@ r(157, WheelOfFortune, "Wheel of Fortune", GI.GT_TAROCK, 1, 0, GI.SL_BALANCED)
 r(158, ImperialTrumps, "Imperial Trumps", GI.GT_TAROCK, 1, -1, GI.SL_BALANCED)
 r(159, Pagat, "Pagat", GI.GT_TAROCK | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
 r(160, Skiz, "Skiz", GI.GT_TAROCK | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
-r(161, FifteenPlus, "Fifteen plus", GI.GT_TAROCK, 1, 0, GI.SL_BALANCED)
+r(161, FifteenPlus, "Fifteen Plus", GI.GT_TAROCK, 1, 0, GI.SL_BALANCED)
 r(162, Excuse, "Excuse", GI.GT_TAROCK | GI.GT_OPEN, 1, 0, GI.SL_BALANCED)
 r(163, Grasshopper, "Grasshopper", GI.GT_TAROCK, 1, 1, GI.SL_MOSTLY_SKILL)
 r(164, DoubleGrasshopper, "Double Grasshopper", GI.GT_TAROCK, 2, 1,
