@@ -21,31 +21,22 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import CautiousDefaultHint
-
-from pysollib.util import ACE, JACK, KING, NO_RANK
-
+from pysollib.layout import Layout
 from pysollib.stack import \
         DealRowTalonStack, \
         InitialDealTalonStack, \
         RedealTalonStack, \
+        SS_FoundationStack, \
         StackWrapper, \
         TalonStack, \
         UD_RK_RowStack, \
-        UD_SS_RowStack, \
-        SS_FoundationStack
+        UD_SS_RowStack
+from pysollib.util import ACE, JACK, KING, NO_RANK
 
 
-# ************************************************************************
-# *
-# ************************************************************************
-
 class StHelena_Talon(TalonStack):
 
     def canDealCards(self):
@@ -332,6 +323,7 @@ registerGame(GameInfo(302, StHelena, "St. Helena",
 registerGame(GameInfo(408, BoxKite, "Box Kite",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(620, LesQuatreCoins, "Les Quatre Coins",
-                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_SKILL))
+                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_SKILL,
+                      altnames=("Four Corners",)))
 registerGame(GameInfo(621, RegalFamily, "Regal Family",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED))
