@@ -557,6 +557,11 @@ class OptionsMenuDialog(LMenuDialog):
                               self.menubar.tkopt.shuffle,
                               self.menubar.mOptEnableShuffle)
 
+            self.addCheckNode(tv, rg,
+                              _('Free hints'),
+                              self.menubar.tkopt.free_hint,
+                              self.menubar.mOptFreeHints)
+
             self.addCheckNode(tv, rg,
                               _('Enable highlight piles'),
                               self.menubar.tkopt.highlight_piles,
@@ -577,6 +582,11 @@ class OptionsMenuDialog(LMenuDialog):
                               self.menubar.tkopt.highlight_not_matching,
                               self.menubar.mOptEnableHighlightNotMatching)
 
+            self.addCheckNode(tv, rg,
+                              _('Stuck notification'),
+                              self.menubar.tkopt.stuck_notification,
+                              self.menubar.mOptEnableStuckNotification)
+
             # submenu.add_separator()
 
             self.addCheckNode(tv, rg,
@@ -875,7 +885,7 @@ class OptionsMenuDialog(LMenuDialog):
                     self.menubar.mOptTableColor)
 
             rg1 = tv.add_node(
-                LTreeNode(text=_('Textures')), rg)
+                LTreeNode(text=_('Tiles')), rg)
             rg2 = tv.add_node(
                 LTreeNode(text=_('Images')), rg)
 
@@ -1250,11 +1260,13 @@ class PysolMenubarTk:
             undo=BooleanVar(),
             bookmarks=BooleanVar(),
             hint=BooleanVar(),
+            free_hint=BooleanVar(),
             shuffle=BooleanVar(),
             highlight_piles=BooleanVar(),
             highlight_cards=BooleanVar(),
             highlight_samerank=BooleanVar(),
             highlight_not_matching=BooleanVar(),
+            stuck_notification=BooleanVar(),
             mahjongg_show_removed=BooleanVar(),
             shisen_show_hint=BooleanVar(),
             accordion_deal_all=BooleanVar(),
@@ -1310,12 +1322,14 @@ class PysolMenubarTk:
         tkopt.quickplay.set(opt.quickplay)
         tkopt.undo.set(opt.undo)
         tkopt.hint.set(opt.hint)
+        tkopt.free_hint.set(opt.free_hint)
         tkopt.shuffle.set(opt.shuffle)
         tkopt.bookmarks.set(opt.bookmarks)
         tkopt.highlight_piles.set(opt.highlight_piles)
         tkopt.highlight_cards.set(opt.highlight_cards)
         tkopt.highlight_samerank.set(opt.highlight_samerank)
         tkopt.highlight_not_matching.set(opt.highlight_not_matching)
+        tkopt.stuck_notification.set(opt.stuck_notification)
         tkopt.shrink_face_down.set(opt.shrink_face_down)
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
@@ -1339,8 +1353,6 @@ class PysolMenubarTk:
         tkopt.toolbar_size.set(opt.toolbar_size)
         tkopt.toolbar_relief.set(opt.toolbar_relief)
         tkopt.statusbar.set(opt.statusbar)
-        tkopt.num_cards.set(opt.num_cards)
-        tkopt.helpbar.set(opt.helpbar)
         tkopt.save_games_geometry.set(opt.save_games_geometry)
         tkopt.demo_logo.set(opt.demo_logo)
         tkopt.splashscreen.set(opt.splashscreen)
@@ -2029,6 +2041,12 @@ the next time you restart the %(app)s""") % {'app': TITLE})
         self.app.opt.hint = self.tkopt.hint.get()
         self.game.updateMenus()
 
+    def mOptFreeHints(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.free_hint = self.tkopt.free_hint.get()
+        self.game.updateMenus()
+
     def mOptEnableShuffle(self, *args):
         if self._cancelDrag(break_pause=False):
             return
@@ -2060,6 +2078,12 @@ the next time you restart the %(app)s""") % {'app': TITLE})
             self.tkopt.highlight_not_matching.get()
         # self.game.updateMenus()
 
+    def mOptEnableStuckNotification(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.stuck_notification = self.tkopt.stuck_notification.get()
+        # self.game.updateMenus()
+
     def mOptAnimations(self, *args):
         if self._cancelDrag(break_pause=False):
             return
