@@ -28,10 +28,10 @@ import traceback
 import configobj
 
 import pysollib.settings
-from pysollib.mfxutil import USE_PIL, print_err
+from pysollib.mfxutil import Image, USE_PIL, print_err
 from pysollib.mygettext import _
 from pysollib.mygettext import myGettext
-from pysollib.pysoltk import TOOLBAR_BUTTONS, TOOLKIT
+from pysollib.pysoltk import STATUSBAR_ITEMS, TOOLBAR_BUTTONS, TOOLKIT
 from pysollib.resource import CSI
 
 
@@ -72,10 +72,12 @@ shuffle = boolean
 undo = boolean
 bookmarks = boolean
 hint = boolean
+free_hint = boolean
 highlight_piles = boolean
 highlight_cards = boolean
 highlight_samerank = boolean
 highlight_not_matching = boolean
+stuck_notification = boolean
 mahjongg_show_removed = boolean
 mahjongg_create_solvable = integer(0, 2)
 shisen_show_hint = boolean
@@ -98,10 +100,6 @@ toolbar_relief = string
 toolbar_compound = string
 toolbar_size = integer(0, 2)
 statusbar = boolean
-statusbar_game_number = boolean
-statusbar_stuck = boolean
-num_cards = boolean
-helpbar = boolean
 num_recent_games = integer(10, 100)
 last_gameid = integer
 game_holded = integer
@@ -122,10 +120,12 @@ sound_sample_volume = integer(0, 128)
 sound_sample_buffer_size = integer(1, 4)
 music = boolean
 tabletile_name = string
+tabletile_scale_method = integer
 center_layout = boolean
 recent_gameid = int_list
 favorite_gameid = int_list
 visible_buttons = string_list
+visible_status = string_list
 translate_game_names = boolean
 solver_presets = string_list
 solver_show_progress = boolean
@@ -203,6 +203,7 @@ scale_y = float
 auto_scale = boolean
 spread_stacks = boolean
 preserve_aspect_ratio = boolean
+resampling = integer(0, 10)
 '''.splitlines()
 
 
@@ -219,10 +220,12 @@ class Options:
         ('undo', 'bool'),
         ('bookmarks', 'bool'),
         ('hint', 'bool'),
+        ('free_hint', 'bool'),
         ('highlight_piles', 'bool'),
         ('highlight_cards', 'bool'),
         ('highlight_samerank', 'bool'),
         ('highlight_not_matching', 'bool'),
+        ('stuck_notification', 'bool'),
         ('mahjongg_show_removed', 'bool'),
         ('mahjongg_create_solvable', 'int'),
         ('shisen_show_hint', 'bool'),
@@ -247,10 +250,10 @@ class Options:
         ('toolbar_compound', 'str'),
         ('toolbar_size', 'int'),
         ('statusbar', 'bool'),
-        ('statusbar_game_number', 'bool'),
-        ('statusbar_stuck', 'bool'),
-        ('num_cards', 'bool'),
-        ('helpbar', 'bool'),
+        # ('statusbar_game_number', 'bool'),
+        # ('statusbar_stuck', 'bool'),
+        # ('num_cards', 'bool'),
+        # ('helpbar', 'bool'),
         ('num_recent_games', 'int'),
         ('last_gameid', 'int'),
         ('game_holded', 'int'),
@@ -272,6 +275,7 @@ class Options:
         ('sound_sample_buffer_size', 'int'),
         ('music', 'bool'),
         ('tabletile_name', 'str'),
+        ('tabletile_scale_method', 'int'),
         ('center_layout', 'bool'),
         ('translate_game_names', 'bool'),
         ('solver_presets', 'list'),
@@ -307,10 +311,12 @@ class Options:
         self.undo = True
         self.bookmarks = True
         self.hint = True
+        self.free_hint = False
         self.highlight_piles = True
         self.highlight_cards = True
         self.highlight_samerank = True
         self.highlight_not_matching = True
+        self.stuck_notification = False
         self.mahjongg_show_removed = False
         self.mahjongg_create_solvable = 2  # 0 - none, 1 - easy, 2 - hard
         self.accordion_deal_all = True
@@ -345,11 +351,14 @@ class Options:
         self.toolbar_vars = {}
         for w in TOOLBAR_BUTTONS:
             self.toolbar_vars[w] = True  # show all buttons
+        self.statusbar_vars = {}
+        for w, x in STATUSBAR_ITEMS:
+            self.statusbar_vars[w] = True
         self.statusbar = True
-        self.statusbar_game_number = False  # show game number in statusbar
-        self.statusbar_stuck = False        # show stuck indicator
-        self.num_cards = False
-        self.helpbar = False
+        # self.statusbar_game_number = False  # show game number in statusbar
+        # self.statusbar_stuck = False        # show stuck indicator
+        # self.num_cards = False
+        # self.helpbar = False
         self.splashscreen = True
         self.date_format = '%m-%d'
         self.mouse_button1 = 1
@@ -454,6 +463,10 @@ class Options:
         self.spread_stacks = False
         self.center_layout = True
         self.preserve_aspect_ratio = True
+        self.tabletile_scale_method = 0
+        self.resampling = 0
+        if USE_PIL:
+            self.resampling = int(Image.ANTIALIAS)
         # solver
         self.solver_presets = [
             'none',
@@ -583,6 +596,9 @@ class Options:
         visible_buttons = [b for b in self.toolbar_vars
                            if self.toolbar_vars[b]]
         config['general']['visible_buttons'] = visible_buttons
+        visible_status = [b for b in self.statusbar_vars
+                          if self.statusbar_vars[b]]
+        config['general']['visible_status'] = visible_status
         if 'none' in config['general']['solver_presets']:
             config['general']['solver_presets'].remove('none')
 
@@ -608,7 +624,7 @@ class Options:
             config['cardsets'][str(key)] = val
         for key in ('scale_cards', 'scale_x', 'scale_y',
                     'auto_scale', 'spread_stacks',
-                    'preserve_aspect_ratio'):
+                    'preserve_aspect_ratio', 'resampling'):
             config['cardsets'][key] = getattr(self, key)
 
         # games_geometry
@@ -724,6 +740,10 @@ class Options:
         if visible_buttons is not None:
             for key in TOOLBAR_BUTTONS:
                 self.toolbar_vars[key] = (key in visible_buttons)
+        visible_status = self._getOption('general', 'visible_status', 'list')
+        if visible_status is not None:
+            for key, label in STATUSBAR_ITEMS:
+                self.statusbar_vars[key] = (key in visible_status)
 
         myGettext.language = self.language
 
@@ -779,7 +799,8 @@ class Options:
                        ('scale_y', 'float'),
                        ('auto_scale', 'bool'),
                        ('spread_stacks', 'bool'),
-                       ('preserve_aspect_ratio', 'bool')):
+                       ('preserve_aspect_ratio', 'bool'),
+                       ('resampling', 'int')):
             val = self._getOption('cardsets', key, t)
             if val is not None:
                 setattr(self, key, val)
