@@ -1,45 +1,53 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 
-# imports
-import os, sys, time
-import gtk, gobject, pango
+import sys
+import time
+
+import gobject
+
+import gtk
 import gtk.glade
 
-# PySol imports
+import pango
+
 from pysollib.mfxutil import format_time
-from pysollib.settings import TOP_TITLE, TITLE
+from pysollib.mygettext import _
+from pysollib.settings import TITLE
 from pysollib.stats import PysolStatsFormatter
 
-# Toolkit imports
-from tkwidget import MfxDialog, MfxMessageDialog
+from tkwidget import MfxMessageDialog
 
+if sys.version_info > (3,):
+    def cmp(a, b):
+        return ((b > a)-(a > b))
 
 # ************************************************************************
 # *
 # ************************************************************************
 
+
 class StatsFormatter(PysolStatsFormatter):
 
     def __init__(self, app, store):
@@ -59,7 +67,8 @@ class StatsFormatter(PysolStatsFormatter):
                            6, result[6],
                            7, result[7])
         total, played, won, lost, time, moves, perc = self.getStatSummary()
-        text = _("Total (%d out of %d games)") % (played, total)
+        text = _("Total (%(played)d out of %(total)d games)") % {
+            'played': played, 'total': total}
         iter = self.store.append(None)
         self.store.set(iter,
                        0, text,
@@ -116,19 +125,16 @@ class Game_StatsDialog:
         self.player = player
         self.gameid = gameid
         self.games = {}
-        self.games_id = [] # sorted by name
+        self.games_id = []  # sorted by name
         #
         glade_file = app.dataloader.findFile('pysolfc.glade')
         #
         games = app.gdb.getGamesIdSortedByName()
         n = 0
-        current = 0
         for id in games:
             won, lost = self.app.stats.getStats(self.player, id)
             if won+lost > 0 or id == gameid:
                 gi = app.gdb.get(id)
-                if id == gameid:
-                    current = n
                 self.games[n] = gi
                 self.games_id.append(id)
                 n += 1
@@ -136,7 +142,7 @@ class Game_StatsDialog:
         self.widgets_tree = gtk.glade.XML(glade_file)
         #
         table = self.widgets_tree.get_widget('current_game_table')
-        combo = self._createGameCombo(table, 1, 0, self._currentComboChanged)
+        self._createGameCombo(table, 1, 0, self._currentComboChanged)
         # total
         self._createText('total')
         drawing = self.widgets_tree.get_widget('total_drawingarea')
@@ -147,7 +153,7 @@ class Game_StatsDialog:
         drawing.connect('expose_event', self._drawingExposeEvent, 'session')
         # top 10
         table = self.widgets_tree.get_widget('top_10_table')
-        combo = self._createGameCombo(table, 1, 0, self._top10ComboChanged)
+        self._createGameCombo(table, 1, 0, self._top10ComboChanged)
         self._createTop()
         self._updateTop(gameid)
         # all games stat
@@ -174,7 +180,6 @@ class Game_StatsDialog:
         self.status = -1
         dialog.destroy()
 
-
     def _translateLabels(self):
         # mnemonic
         for n in (
@@ -187,7 +192,7 @@ class Game_StatsDialog:
             'label16',
             'label17',
             'label18',
-            ):
+                ):
             w = self.widgets_tree.get_widget(n)
             w.set_text_with_mnemonic(_(w.get_label()))
         # simple
@@ -196,7 +201,7 @@ class Game_StatsDialog:
             'label6',
             'label7',
             'label14'
-            ):
+                ):
             w = self.widgets_tree.get_widget(n)
             w.set_text(_(w.get_text()))
         # markup
@@ -213,18 +218,17 @@ class Game_StatsDialog:
             'label22',
             'label23',
             'label24',
-            ):
+                ):
             w = self.widgets_tree.get_widget(n)
             s = _(w.get_label())
             w.set_markup('<b>%s</b>' % s)
 
-
     def _createGameCombo(self, table, x, y, callback):
         combo = gtk.combo_box_new_text()
         combo.show()
         table.attach(combo,
                      x, x+1,                y, y+1,
-                     gtk.FILL|gtk.EXPAND,   0,
+                     gtk.FILL | gtk.EXPAND,   0,
                      4,                     4)
         #
         n = 0
@@ -236,8 +240,7 @@ class Game_StatsDialog:
                 current = n
             n += 1
         combo.set_active(current)
-        combo.connect('changed', callback) #self._comboChanged)
-
+        combo.connect('changed', callback)  # self._comboChanged)
 
     def _currentComboChanged(self, w):
         gi = self.games[w.get_active()]
@@ -249,17 +252,16 @@ class Game_StatsDialog:
         drawing = self.widgets_tree.get_widget('session_drawingarea')
         self._createChart(drawing, 'session')
 
-
     def _top10ComboChanged(self, w):
         gi = self.games[w.get_active()]
         self._updateTop(gi.id)
 
-
     def _createText(self, name):
         if name == 'total':
             won, lost = self.app.stats.getStats(self.player, self.gameid)
         else:
-            won, lost = self.app.stats.getSessionStats(self.player, self.gameid)
+            won, lost = self.app.stats.getSessionStats(
+                self.player, self.gameid)
         pwon, plost = self._getPwon(won, lost)
         label = self.widgets_tree.get_widget(name+'_num_won_label')
         label.set_text(str(won))
@@ -272,16 +274,15 @@ class Game_StatsDialog:
         label = self.widgets_tree.get_widget(name+'_num_total_label')
         label.set_text(str(won+lost))
 
-
     def _drawingExposeEvent(self, drawing, e, frame):
         self._createChart(drawing, frame)
 
-
     def _createChart(self, drawing, frame):
         if frame == 'total':
             won, lost = self.app.stats.getStats(self.player, self.gameid)
         else:
-            won, lost = self.app.stats.getSessionStats(self.player, self.gameid)
+            won, lost = self.app.stats.getSessionStats(
+                self.player, self.gameid)
         pwon, plost = self._getPwon(won, lost)
         s, ewon, elost = 0, int(360.0*pwon), int(360.0*plost)
 
@@ -293,10 +294,10 @@ class Game_StatsDialog:
         alloc = drawing.allocation
         width, height = alloc.width, alloc.height
         w, h = 90, 50
-        ##x, y = 10, 10
-        x, y = (width-w)/2, (height-h)/2
+        # x, y = 10, 10
+        x, y = (width-w)//2, (height-h)//2
         dy = 9
-        y = y-dy/2
+        y -= dy//2
 
         if won+lost > 0:
             gc.set_foreground(colormap.alloc_color('#008000'))
@@ -327,9 +328,8 @@ class Game_StatsDialog:
             gc.set_foreground(colormap.alloc_color('#a0a0a0'))
             pangolayout = drawing.create_pango_layout(_('No games'))
             ext = pangolayout.get_extents()
-            tw, th = ext[1][2]/pango.SCALE, ext[1][3]/pango.SCALE
-            win.draw_layout(gc, x+w/2-tw/2, y+h/2-th/2, pangolayout)
-
+            tw, th = ext[1][2]//pango.SCALE, ext[1][3]//pango.SCALE
+            win.draw_layout(gc, x+w//2-tw//2, y+h//2-th//2, pangolayout)
 
     def _createTop(self):
         for n in ('top_10_time_treeview',
@@ -337,14 +337,15 @@ class Game_StatsDialog:
                   'top_10_total_moves_treeview'):
             self._createTopList(n)
 
-
     def _updateTop(self, gameid):
-        if (self.player not in self.app.stats.games_stats or
-            gameid not in self.app.stats.games_stats[self.player] or
-            not self.app.stats.games_stats[self.player][gameid].time_result.top):
+        s = self.app.stats.games_stats
+        cond = (self.player not in s or
+                gameid not in s[self.player] or
+                not s[self.player][gameid].time_result.top)
+        if cond:
             return
 
-        s = self.app.stats.games_stats[self.player][gameid]
+        s = s[self.player][gameid]
 
         label = self.widgets_tree.get_widget('playing_time_minimum_label')
         label.set_text(format_time(s.time_result.min))
@@ -370,17 +371,17 @@ class Game_StatsDialog:
         for n, ss in (
             ('top_10_time_treeview',        s.time_result.top),
             ('top_10_moves_treeview',       s.moves_result.top),
-            ('top_10_total_moves_treeview', s.total_moves_result.top)):
+            ('top_10_total_moves_treeview', s.total_moves_result.top)
+                ):
             self._updateTopList(n, ss)
 
-
     def _createTopList(self, tv_name):
         treeview = self.widgets_tree.get_widget(tv_name)
         store = gtk.ListStore(gobject.TYPE_INT,    # N
-                              gobject.TYPE_STRING, # number
-                              gobject.TYPE_STRING, # started at
-                              gobject.TYPE_STRING, # result
-                              gobject.TYPE_STRING, # result
+                              gobject.TYPE_STRING,  # number
+                              gobject.TYPE_STRING,  # started at
+                              gobject.TYPE_STRING,  # result
+                              gobject.TYPE_STRING,  # result
                               )
         treeview.set_model(store)
         n = 0
@@ -389,14 +390,13 @@ class Game_StatsDialog:
             _('Game number'),
             _('Started at'),
             _('Result'),
-            ):
+                ):
             column = gtk.TreeViewColumn(label, gtk.CellRendererText(), text=n)
             column.set_resizable(True)
-            ##column.set_sort_column_id(n)
+            # column.set_sort_column_id(n)
             treeview.append_column(column)
             n += 1
 
-
     def _updateTopList(self, tv_name, top):
         treeview = self.widgets_tree.get_widget(tv_name)
         store = treeview.get_model()
@@ -415,7 +415,6 @@ class Game_StatsDialog:
             store.set(iter, 0, row, 1, i.game_number, 2, t, 3, r)
             row += 1
 
-
     def _createStatsList(self):
         treeview = self.widgets_tree.get_widget('all_games_treeview')
         n = 0
@@ -427,7 +426,7 @@ class Game_StatsDialog:
             _('Playing time'),
             _('Moves'),
             _('% won'),
-            ):
+                ):
             column = gtk.TreeViewColumn(label, gtk.CellRendererText(),
                                         text=n)
             column.set_resizable(True)
@@ -435,13 +434,13 @@ class Game_StatsDialog:
             treeview.append_column(column)
             n += 1
         #
-        store = gtk.ListStore(gobject.TYPE_STRING, # name
+        store = gtk.ListStore(gobject.TYPE_STRING,  # name
                               gobject.TYPE_INT,    # played
                               gobject.TYPE_INT,    # won
                               gobject.TYPE_INT,    # lost
-                              gobject.TYPE_STRING, # playing time
-                              gobject.TYPE_STRING, # moves
-                              gobject.TYPE_STRING, # % won
+                              gobject.TYPE_STRING,  # playing time
+                              gobject.TYPE_STRING,  # moves
+                              gobject.TYPE_STRING,  # % won
                               gobject.TYPE_INT,    # gameid
                               )
         sortable = gtk.TreeModelSort(store)
@@ -452,7 +451,6 @@ class Game_StatsDialog:
         treeview.set_rules_hint(True)
         return store
 
-
     def _createLogList(self, name):
         #
         treeview = self.widgets_tree.get_widget(name)
@@ -462,7 +460,7 @@ class Game_StatsDialog:
             _('Game number'),
             _('Started at'),
             _('Status'),
-            ):
+                ):
             column = gtk.TreeViewColumn(label, gtk.CellRendererText(),
                                         text=n)
             column.set_resizable(True)
@@ -470,17 +468,16 @@ class Game_StatsDialog:
             treeview.append_column(column)
             n += 1
         #
-        store = gtk.ListStore(gobject.TYPE_STRING, # game name
-                              gobject.TYPE_STRING, # game number
-                              gobject.TYPE_STRING, # started at
-                              gobject.TYPE_STRING, # status
-                              gobject.TYPE_INT,    # gameid
+        store = gtk.ListStore(gobject.TYPE_STRING,  # game name
+                              gobject.TYPE_STRING,  # game number
+                              gobject.TYPE_STRING,  # started at
+                              gobject.TYPE_STRING,  # status
+                              gobject.TYPE_INT,     # gameid
                               )
         treeview.set_model(store)
         treeview.set_rules_hint(True)
         return store
 
-
     def _getPwon(self, won, lost):
         pwon, plost = 0.0, 0.0
         if won + lost > 0:
@@ -489,7 +486,6 @@ class Game_StatsDialog:
             plost = 1.0 - pwon
         return pwon, plost
 
-
     def _cmpPlayingTime(self, store, iter1, iter2):
         val1 = store.get_value(iter1, 4)
         val2 = store.get_value(iter2, 4)
@@ -523,24 +519,23 @@ Top_StatsDialog = Game_StatsDialog
 # *
 # ************************************************************************
 
-class Status_StatsDialog(MfxMessageDialog): #MfxDialog
+class Status_StatsDialog(MfxMessageDialog):  # MfxDialog
     def __init__(self, parent, game):
         stats, gstats = game.stats, game.gstats
         w1 = w2 = ''
-        n = 0
-        for s in game.s.foundations:
-            n = n + len(s.cards)
+        n = sum([len(s.cards) for s in game.s.foundations])
         w1 = (_('Highlight piles: ') + str(stats.highlight_piles) + '\n' +
               _('Highlight cards: ') + str(stats.highlight_cards) + '\n' +
-              _('Highlight same rank: ') + str(stats.highlight_samerank) + '\n')
+              _('Highlight same rank: ') +
+              str(stats.highlight_samerank) + '\n')
         if game.s.talon:
             if game.gameinfo.redeals != 0:
-                w2 = w2 + _('\nRedeals: ') + str(game.s.talon.round - 1)
-            w2 = w2 + _('\nCards in Talon: ') + str(len(game.s.talon.cards))
+                w2 += _('\nRedeals: ') + str(game.s.talon.round - 1)
+            w2 += _('\nCards in Talon: ') + str(len(game.s.talon.cards))
         if game.s.waste and game.s.waste not in game.s.foundations:
-            w2 = w2 + _('\nCards in Waste: ') + str(len(game.s.waste.cards))
+            w2 += _('\nCards in Waste: ') + str(len(game.s.waste.cards))
         if game.s.foundations:
-            w2 = w2 + _('\nCards in Foundations: ') + str(n)
+            w2 += _('\nCards in Foundations: ') + str(n)
         #
         date = time.strftime('%Y-%m-%d %H:%M',
                              time.localtime(game.gstats.start_time))
@@ -549,7 +544,7 @@ class Status_StatsDialog(MfxMessageDialog): #MfxDialog
             text=game.getTitleName() + '\n' +
             game.getGameNumber(format=1) + '\n' +
             _('Playing time: ') + game.getTime() + '\n' +
-            _('Started at: ') + date + '\n\n'+
+            _('Started at: ') + date + '\n\n' +
             _('Moves: ') + str(game.moves.index) + '\n' +
             _('Undo moves: ') + str(stats.undo_moves) + '\n' +
             _('Bookmark moves: ') + str(gstats.goto_bookmark_moves) + '\n' +
@@ -570,6 +565,3 @@ class Status_StatsDialog(MfxMessageDialog): #MfxDialog
 class ProgressionDialog:
     # FIXME
     pass
-
-
-
