@@ -1,5 +1,6 @@
 import math
 import os
+import platform
 import re
 import sys
 
@@ -13,7 +14,7 @@ from pysollib.settings import TITLE, WIN_SYSTEM
 from pysollib.settings import USE_FREECELL_SOLVER
 from pysollib.ui.tktile.tkconst import COMPOUNDS, CURSOR_WATCH, EVENT_HANDLED
 from pysollib.ui.tktile.tkconst import EVENT_PROPAGATE
-from pysollib.ui.tktile.tkconst import TOOLBAR_BUTTONS
+from pysollib.ui.tktile.tkconst import STATUSBAR_ITEMS, TOOLBAR_BUTTONS
 from pysollib.ui.tktile.tkutil import after_idle, bind
 
 from six.moves import tkinter
@@ -39,9 +40,9 @@ def createToolbarMenu(menubar, menu):
     submenu.add_radiobutton(label=n_("Large icons"),
                             variable=menubar.tkopt.toolbar_size, value=1,
                             command=menubar.mOptToolbarSize)
-    # submenu.add_radiobutton(label=n_("Extra large icons"),
-    #                         variable=menubar.tkopt.toolbar_size, value=2,
-    #                         command=menubar.mOptToolbarSize)
+    submenu.add_radiobutton(label=n_("Extra large icons"),
+                            variable=menubar.tkopt.toolbar_size, value=2,
+                            command=menubar.mOptToolbarSize)
     submenu = MfxMenu(menu, label=n_('Compound'), tearoff=tearoff)
     for comp, label in COMPOUNDS:
         submenu.add_radiobutton(
@@ -71,6 +72,58 @@ def createToolbarMenu(menubar, menu):
                          command=menubar.mOptToolbar)
 
 
+def createStatusbarMenu(menubar, menu):
+    menu.add_checkbutton(
+        label=n_("Show &statusbar"), variable=menubar.tkopt.statusbar,
+        command=menubar.mOptStatusbar)
+    menu.add_separator()
+    for comp, label in STATUSBAR_ITEMS:
+        menu.add_checkbutton(
+            label=label,
+            variable=menubar.tkopt.statusbar_vars[comp],
+            command=lambda m=menubar, w=comp: m.mOptStatusbarConfig(w))
+
+
+def createResamplingMenu(menubar, menu):
+    tearoff = menu.cget('tearoff')
+    submenu = MfxMenu(menu, label=n_('R&esampling'), tearoff=tearoff)
+
+    submenu.add_radiobutton(label=n_("&Nearest Neighbor"),
+                            variable=menubar.tkopt.resampling,
+                            value=int(Image.NEAREST),
+                            command=menubar.mOptResampling)
+    if Image.BILINEAR:
+        submenu.add_radiobutton(label=n_("&Bilinear"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.BILINEAR),
+                                command=menubar.mOptResampling)
+    if Image.BICUBIC:
+        submenu.add_radiobutton(label=n_("B&icubic"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.BICUBIC),
+                                command=menubar.mOptResampling)
+    if Image.LANCZOS:
+        submenu.add_radiobutton(label=n_("&Lanczos"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.LANCZOS),
+                                command=menubar.mOptResampling)
+    elif Image.ANTIALIAS:
+        submenu.add_radiobutton(label=n_("&Antialiasing"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.ANTIALIAS),
+                                command=menubar.mOptResampling)
+    if Image.BOX:
+        submenu.add_radiobutton(label=n_("B&ox"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.BOX),
+                                command=menubar.mOptResampling)
+    if Image.HAMMING:
+        submenu.add_radiobutton(label=n_("&Hamming"),
+                                variable=menubar.tkopt.resampling,
+                                value=int(Image.HAMMING),
+                                command=menubar.mOptResampling)
+
+
 # ************************************************************************
 # *
 # ************************************************************************
@@ -164,11 +217,13 @@ class PysolMenubarTkCommon:
             undo=tkinter.BooleanVar(),
             bookmarks=tkinter.BooleanVar(),
             hint=tkinter.BooleanVar(),
+            free_hint=tkinter.BooleanVar(),
             shuffle=tkinter.BooleanVar(),
             highlight_piles=tkinter.BooleanVar(),
             highlight_cards=tkinter.BooleanVar(),
             highlight_samerank=tkinter.BooleanVar(),
             highlight_not_matching=tkinter.BooleanVar(),
+            stuck_notification=tkinter.BooleanVar(),
             mahjongg_show_removed=tkinter.BooleanVar(),
             shisen_show_hint=tkinter.BooleanVar(),
             accordion_deal_all=tkinter.BooleanVar(),
@@ -176,6 +231,7 @@ class PysolMenubarTkCommon:
             sound=tkinter.BooleanVar(),
             auto_scale=tkinter.BooleanVar(),
             preserve_aspect_ratio=tkinter.BooleanVar(),
+            resampling=tkinter.IntVar(),
             spread_stacks=tkinter.BooleanVar(),
             center_layout=tkinter.BooleanVar(),
             save_games_geometry=tkinter.BooleanVar(),
@@ -205,9 +261,12 @@ class PysolMenubarTkCommon:
             pause=tkinter.BooleanVar(),
             theme=tkinter.StringVar(),
             toolbar_vars={},
+            statusbar_vars={},
         )
         for w in TOOLBAR_BUTTONS:
             self.tkopt.toolbar_vars[w] = tkinter.BooleanVar()
+        for w, x in STATUSBAR_ITEMS:
+            self.tkopt.statusbar_vars[w] = tkinter.BooleanVar()
 
     def _setOptions(self):
         tkopt, opt = self.tkopt, self.app.opt
@@ -218,12 +277,14 @@ class PysolMenubarTkCommon:
         tkopt.quickplay.set(opt.quickplay)
         tkopt.undo.set(opt.undo)
         tkopt.hint.set(opt.hint)
+        tkopt.free_hint.set(opt.free_hint)
         tkopt.shuffle.set(opt.shuffle)
         tkopt.bookmarks.set(opt.bookmarks)
         tkopt.highlight_piles.set(opt.highlight_piles)
         tkopt.highlight_cards.set(opt.highlight_cards)
         tkopt.highlight_samerank.set(opt.highlight_samerank)
         tkopt.highlight_not_matching.set(opt.highlight_not_matching)
+        tkopt.stuck_notification.set(opt.stuck_notification)
         tkopt.shrink_face_down.set(opt.shrink_face_down)
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
         tkopt.randomize_place.set(opt.randomize_place)
@@ -234,6 +295,7 @@ class PysolMenubarTkCommon:
         tkopt.sound.set(opt.sound)
         tkopt.auto_scale.set(opt.auto_scale)
         tkopt.preserve_aspect_ratio.set(opt.preserve_aspect_ratio)
+        tkopt.resampling.set(opt.resampling)
         tkopt.spread_stacks.set(opt.spread_stacks)
         tkopt.center_layout.set(opt.center_layout)
         tkopt.save_games_geometry.set(opt.save_games_geometry)
@@ -251,8 +313,8 @@ class PysolMenubarTkCommon:
         tkopt.toolbar_size.set(opt.toolbar_size)
         tkopt.toolbar_relief.set(opt.toolbar_relief)
         tkopt.statusbar.set(opt.statusbar)
-        tkopt.num_cards.set(opt.num_cards)
-        tkopt.helpbar.set(opt.helpbar)
+        # tkopt.num_cards.set(opt.num_cards)
+        # tkopt.helpbar.set(opt.helpbar)
         tkopt.demo_logo.set(opt.demo_logo)
         tkopt.splashscreen.set(opt.splashscreen)
         tkopt.mouse_type.set(opt.mouse_type)
@@ -260,6 +322,8 @@ class PysolMenubarTkCommon:
         tkopt.negative_bottom.set(opt.negative_bottom)
         for w in TOOLBAR_BUTTONS:
             tkopt.toolbar_vars[w].set(opt.toolbar_vars.get(w, False))
+        for w, x in STATUSBAR_ITEMS:
+            tkopt.statusbar_vars[w].set(opt.statusbar_vars.get(w, False))
 
     def connectGame(self, game):
         self.game = game
@@ -508,6 +572,9 @@ class PysolMenubarTkCommon:
         submenu.add_checkbutton(
             label=n_("Enable shu&ffle"), variable=self.tkopt.shuffle,
             command=self.mOptEnableShuffle)
+        submenu.add_checkbutton(
+            label=n_("Free hin&ts"), variable=self.tkopt.free_hint,
+            command=self.mOptFreeHints)
         submenu.add_checkbutton(
             label=n_("Enable highlight p&iles"),
             variable=self.tkopt.highlight_piles,
@@ -524,6 +591,10 @@ class PysolMenubarTkCommon:
             label=n_("Highlight &no matching"),
             variable=self.tkopt.highlight_not_matching,
             command=self.mOptEnableHighlightNotMatching)
+        submenu.add_checkbutton(
+            label=n_("Stuc&k notification"),
+            variable=self.tkopt.stuck_notification,
+            command=self.mOptEnableStuckNotification)
         submenu.add_separator()
         submenu.add_checkbutton(
             label=n_("&Show removed tiles (in Mahjongg games)"),
@@ -565,6 +636,8 @@ class PysolMenubarTkCommon:
                 label=n_("&Preserve aspect ratio"),
                 variable=self.tkopt.preserve_aspect_ratio,
                 command=self.mOptPreserveAspectRatio)
+            submenu.add_separator()
+            createResamplingMenu(self, submenu)
             submenu = MfxMenu(menu, label=n_("Card la&yout"))
             submenu.add_checkbutton(
                 label=n_("&Spread stacks"), variable=self.tkopt.spread_stacks,
@@ -665,15 +738,7 @@ class PysolMenubarTkCommon:
         submenu = MfxMenu(menu, label=n_("&Toolbar"))
         createToolbarMenu(self, submenu)
         submenu = MfxMenu(menu, label=n_("Stat&usbar"))
-        submenu.add_checkbutton(
-            label=n_("Show &statusbar"), variable=self.tkopt.statusbar,
-            command=self.mOptStatusbar)
-        submenu.add_checkbutton(
-            label=n_("Show &number of cards"), variable=self.tkopt.num_cards,
-            command=self.mOptNumCards)
-        submenu.add_checkbutton(
-            label=n_("Show &help bar"), variable=self.tkopt.helpbar,
-            command=self.mOptHelpbar)
+        createStatusbarMenu(self, submenu)
         menu.add_checkbutton(
             label=n_("&Demo logo"), variable=self.tkopt.demo_logo,
             command=self.mOptDemoLogo)
@@ -796,6 +861,9 @@ class PysolMenubarTkCommon:
         self._bindKey(ctrl, "Up", self.mSelectPrevGameById)
         self._bindKey(ctrl, "Down", self.mSelectNextGameById)
 
+        if os.name == 'posix' and platform.system() != 'Darwin':
+            self._bindKey('Alt-', 'F4', self.mQuit)
+
     #
     # key binding utility
     #
@@ -1411,6 +1479,12 @@ Unsupported game for import.
         self.app.opt.hint = self.tkopt.hint.get()
         self.game.updateMenus()
 
+    def mOptFreeHints(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.free_hint = self.tkopt.free_hint.get()
+        self.game.updateMenus()
+
     def mOptEnableShuffle(self, *args):
         if self._cancelDrag(break_pause=False):
             return
@@ -1442,6 +1516,12 @@ Unsupported game for import.
             self.tkopt.highlight_not_matching.get()
         # self.game.updateMenus()
 
+    def mOptEnableStuckNotification(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.stuck_notification = self.tkopt.stuck_notification.get()
+        # self.game.updateMenus()
+
     def mOptAnimations(self, *args):
         if self._cancelDrag(break_pause=False):
             return
@@ -1592,6 +1672,15 @@ Unsupported game for import.
         self.tkopt.preserve_aspect_ratio.set(preserve_aspect_ratio)
         self._updateCardSize()
 
+    def mOptResampling(self, *event):
+        if self._cancelDrag(break_pause=False):
+            return
+        resampling = self.tkopt.resampling.get()
+        self.app.opt.resampling = resampling
+        self.tkopt.resampling.set(resampling)  # update radiobutton
+        self.app.opt.resampling = (self.tkopt.resampling.get())
+        self._updateCardSize()
+
     def mOptSpreadStacks(self, *event):
         if self._cancelDrag(break_pause=True):
             return
@@ -1670,9 +1759,12 @@ Unsupported game for import.
                 tile.color = d.key
                 if self.app.setTile(0):
                     self.tkopt.tabletile.set(0)
-            elif d.key > 0 and d.key != self.app.tabletile_index:
-                if self.app.setTile(d.key):
+            elif d.key > 0 and (d.key != self.app.tabletile_index or
+                                d.preview_scaling !=
+                                self.app.opt.tabletile_scale_method):
+                if self.app.setTile(d.key, d.preview_scaling):
                     self.tkopt.tabletile.set(d.key)
+                self.app.opt.tabletile_scale_method = d.preview_scaling
 
     def mOptToolbar(self, *event):
         # if self._cancelDrag(break_pause=False): return
@@ -1704,6 +1796,9 @@ Unsupported game for import.
         if self.app.statusbar.show(side, resize=resize):
             self.top.update_idletasks()
 
+    def mOptStatusbarConfig(self, w):
+        self.statusbarConfig(w, self.tkopt.statusbar_vars[w].get())
+
     def mOptNumCards(self, *event):
         if self._cancelDrag(break_pause=False):
             return
@@ -1857,6 +1952,13 @@ Error while saving game.
         self.app.toolbar.config(w, v)
         self.top.update_idletasks()
 
+    def statusbarConfig(self, w, v):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.statusbar_vars[w] = v
+        self.app.statusbar.config(w, v)
+        self.top.update_idletasks()
+
     #
     # stacks descriptions
     #
